@@ -19,12 +19,14 @@
 
 #include "createjob.h"
 
+#include <KLocalizedString>
+
 #include "job_p.h"
 #include "message_p.h"
 #include "rfccodecs.h"
 #include "session_p.h"
 
-namespace KIMAP2
+namespace KIMAP
 {
 class CreateJobPrivate : public JobPrivate
 {
@@ -36,10 +38,10 @@ public:
 };
 }
 
-using namespace KIMAP2;
+using namespace KIMAP;
 
 CreateJob::CreateJob(Session *session)
-    : Job(*new CreateJobPrivate(session, "Create"))
+    : Job(*new CreateJobPrivate(session, i18n("Create")))
 {
 }
 
@@ -50,7 +52,7 @@ CreateJob::~CreateJob()
 void CreateJob::doStart()
 {
     Q_D(CreateJob);
-    d->sendCommand("CREATE", '\"' + KIMAP2::encodeImapFolderName(d->mailBox.toUtf8()) + '\"');
+    d->tags << d->sessionInternal()->sendCommand("CREATE", '\"' + KIMAP::encodeImapFolderName(d->mailBox.toUtf8()) + '\"');
 }
 
 void CreateJob::setMailBox(const QString &mailBox)
